[][src]Struct spectrusty_core::bus::DynamicBus

pub struct DynamicBus<D: BusDevice> { /* fields omitted */ }

A pseudo bus device that allows for adding and removing devices of different types at run time.

The penalty is that the access to the devices must be done using a virtual call dispatch. Also the device of this type can't be cloned (nor the ControlUnit with this device attached).

DynamicBus<D> implements BusDevice itself, so obviously it's possible to declare a statically dispatched downstream BusDevice as its parameter D.

Currently only types implementing BusDevice that are directly terminated with NullDevice can be attached as dynamically dispatched objects.

Implementations

impl<D> DynamicBus<D> where
    D: BusDevice
[src]

pub fn len(&self) -> usize[src]

Returns the number of attached devices.

pub fn is_empty(&self) -> bool[src]

Returns true if there are no devices in the dynamic chain. Otherwise returns false.

pub fn append_device<B>(&mut self, device: B) -> usize where
    B: Into<BoxNamedDynDevice<D::Timestamp>>, 
[src]

Appends an instance of a device at the end of the daisy-chain. Returns its index position in the dynamic device chain.

pub fn remove_device(&mut self) -> Option<BoxNamedDynDevice<D::Timestamp>>[src]

Removes the last device from the dynamic daisy-chain and returns an instance of the boxed dynamic object.

pub fn swap_remove_device(
    &mut self,
    index: usize
) -> BoxNamedDynDevice<D::Timestamp>
[src]

Replaces a device at the given index position and returns it.

The removed device is replaced by the last device of the chain.

Panics

Panics if a device doesn't exist at index.

pub fn replace_device<B>(
    &mut self,
    index: usize,
    device: B
) -> BoxNamedDynDevice<D::Timestamp> where
    B: Into<BoxNamedDynDevice<D::Timestamp>>, 
[src]

Replaces a device at the given index position. Returns the previous device occupying the replaced spot.

Panics

Panics if a device doesn't exist at index.

pub fn clear(&mut self)[src]

Removes all dynamic devices from the dynamic daisy-chain.

pub fn get_device_ref(
    &self,
    index: usize
) -> Option<&NamedDynDevice<D::Timestamp>>
[src]

Returns a reference to a dynamic device at index position in the dynamic daisy-chain.

pub fn get_device_mut(
    &mut self,
    index: usize
) -> Option<&mut NamedDynDevice<D::Timestamp>>
[src]

Returns a mutable reference to a dynamic device at index position in the dynamic daisy-chain.

impl<D> DynamicBus<D> where
    D: BusDevice,
    D::Timestamp: 'static, 
[src]

pub fn remove_as_device<B>(&mut self) -> Option<Box<B>> where
    B: NamedBusDevice<D::Timestamp> + 'static, 
[src]

Removes the last device from the dynamic daisy-chain.

Panics

Panics if a device is not of a type given as parameter B.

pub fn swap_remove_as_device<B>(&mut self, index: usize) -> Box<B> where
    B: NamedBusDevice<D::Timestamp> + 'static, 
[src]

Replaces a device at the given index and returns it.

The removed device is replaced by the last device of the chain.

Panics

Panics if a device doesn't exist at index or if a device is not of a type given as parameter B.

pub fn as_device_ref<B>(&self, index: usize) -> &B where
    B: NamedBusDevice<D::Timestamp> + 'static, 
[src]

Returns a reference to a device of a type B at index in the dynamic daisy-chain.

Panics

Panics if a device doesn't exist at index or if a device is not of a type given as parameter B.

pub fn as_device_mut<B>(&mut self, index: usize) -> &mut B where
    B: NamedBusDevice<D::Timestamp> + 'static, 
[src]

Returns a mutable reference to a device of a type B at index in the dynamic daisy-chain.

Panics

Panics if a device doesn't exist at index or if a device is not of a type given as parameter B.

pub fn is_device<B>(&self, index: usize) -> bool where
    B: NamedBusDevice<D::Timestamp> + 'static, 
[src]

Returns true if a device at index is of a type given as parameter B.

pub fn position_device<B>(&self) -> Option<usize> where
    B: NamedBusDevice<D::Timestamp> + 'static, 
[src]

Searches for a first device of a type given as parameter B, returning its index.

pub fn find_device_ref<B>(&self) -> Option<&B> where
    B: NamedBusDevice<D::Timestamp> + 'static, 
[src]

Searches for a first device of a type given as parameter B, returning a reference to a device.

pub fn find_device_mut<B>(&mut self) -> Option<&mut B> where
    B: NamedBusDevice<D::Timestamp> + 'static, 
[src]

Searches for a first device of a type given as parameter B, returning a mutable reference to a device.