[−][src]Struct spectrusty_core::bus::DynamicSerdeBus
A wrapper for DynamicBus that is able to serialize and deserialize together with currently attached dynamic devices.
Use this type instead of DynamicBus when specifying crate::chip::ControlUnit::BusDevice or BusDevice::NextDevice.
A type that implements SerializeDynDevice and DeserializeDynDevice must be declared as
generic parameter S.
Methods from Deref<Target = DynamicBus<D>>
pub fn len(&self) -> usize[src]
Returns the number of attached devices.
pub fn is_empty(&self) -> bool[src]
Returns true if there are no devices in the dynamic chain. Otherwise returns false.
pub fn append_device<B>(&mut self, device: B) -> usize where
B: Into<BoxNamedDynDevice<D::Timestamp>>, [src]
B: Into<BoxNamedDynDevice<D::Timestamp>>,
Appends an instance of a device at the end of the daisy-chain.
Returns its index position in the dynamic device chain.
pub fn remove_device(&mut self) -> Option<BoxNamedDynDevice<D::Timestamp>>[src]
Removes the last device from the dynamic daisy-chain and returns an instance of the boxed dynamic object.
pub fn swap_remove_device(
&mut self,
index: usize
) -> BoxNamedDynDevice<D::Timestamp>[src]
&mut self,
index: usize
) -> BoxNamedDynDevice<D::Timestamp>
Replaces a device at the given index position and returns it.
The removed device is replaced by the last device of the chain.
Panics
Panics if a device doesn't exist at index.
pub fn replace_device<B>(
&mut self,
index: usize,
device: B
) -> BoxNamedDynDevice<D::Timestamp> where
B: Into<BoxNamedDynDevice<D::Timestamp>>, [src]
&mut self,
index: usize,
device: B
) -> BoxNamedDynDevice<D::Timestamp> where
B: Into<BoxNamedDynDevice<D::Timestamp>>,
Replaces a device at the given index position. Returns the previous device occupying the replaced spot.
Panics
Panics if a device doesn't exist at index.
pub fn clear(&mut self)[src]
Removes all dynamic devices from the dynamic daisy-chain.
pub fn get_device_ref(
&self,
index: usize
) -> Option<&NamedDynDevice<D::Timestamp>>[src]
&self,
index: usize
) -> Option<&NamedDynDevice<D::Timestamp>>
Returns a reference to a dynamic device at index position in the dynamic daisy-chain.
pub fn get_device_mut(
&mut self,
index: usize
) -> Option<&mut NamedDynDevice<D::Timestamp>>[src]
&mut self,
index: usize
) -> Option<&mut NamedDynDevice<D::Timestamp>>
Returns a mutable reference to a dynamic device at index position in the dynamic daisy-chain.
pub fn remove_as_device<B>(&mut self) -> Option<Box<B>> where
B: NamedBusDevice<D::Timestamp> + 'static, [src]
B: NamedBusDevice<D::Timestamp> + 'static,
Removes the last device from the dynamic daisy-chain.
Panics
Panics if a device is not of a type given as parameter B.
pub fn swap_remove_as_device<B>(&mut self, index: usize) -> Box<B> where
B: NamedBusDevice<D::Timestamp> + 'static, [src]
B: NamedBusDevice<D::Timestamp> + 'static,
Replaces a device at the given index and returns it.
The removed device is replaced by the last device of the chain.
Panics
Panics if a device doesn't exist at index or if a device is not of a type given as parameter B.
pub fn as_device_ref<B>(&self, index: usize) -> &B where
B: NamedBusDevice<D::Timestamp> + 'static, [src]
B: NamedBusDevice<D::Timestamp> + 'static,
Returns a reference to a device of a type B at index in the dynamic daisy-chain.
Panics
Panics if a device doesn't exist at index or if a device is not of a type given as parameter B.
pub fn as_device_mut<B>(&mut self, index: usize) -> &mut B where
B: NamedBusDevice<D::Timestamp> + 'static, [src]
B: NamedBusDevice<D::Timestamp> + 'static,
Returns a mutable reference to a device of a type B at index in the dynamic daisy-chain.
Panics
Panics if a device doesn't exist at index or if a device is not of a type given as parameter B.
pub fn is_device<B>(&self, index: usize) -> bool where
B: NamedBusDevice<D::Timestamp> + 'static, [src]
B: NamedBusDevice<D::Timestamp> + 'static,
Returns true if a device at index is of a type given as parameter B.
pub fn position_device<B>(&self) -> Option<usize> where
B: NamedBusDevice<D::Timestamp> + 'static, [src]
B: NamedBusDevice<D::Timestamp> + 'static,
Searches for a first device of a type given as parameter B, returning its index.
pub fn find_device_ref<B>(&self) -> Option<&B> where
B: NamedBusDevice<D::Timestamp> + 'static, [src]
B: NamedBusDevice<D::Timestamp> + 'static,
Searches for a first device of a type given as parameter B, returning a reference to a device.
pub fn find_device_mut<B>(&mut self) -> Option<&mut B> where
B: NamedBusDevice<D::Timestamp> + 'static, [src]
B: NamedBusDevice<D::Timestamp> + 'static,
Searches for a first device of a type given as parameter B, returning a mutable reference to a device.