[−][src]Module spectrusty_core::chip
Chipset emulation building blocks.
Structs
| ColorMode | ULAplus data port flags when register port is set to UlaPlusRegFlags::MODE_GROUP. |
| EarMic | This type represents packed EAR and MIC output data. |
| ParseReadEarModeError | |
| ScldCtrlFlags | Timex TC2048/TC2068/TS2068 screen and memory control flags. |
| ThreadSyncTimer | A tool for synchronizing emulation with a running thread. |
| TryFromU8ColorModeError | |
| TryFromU8EarMicError | |
| TryFromU8Ula3PagingError | |
| Ula3CtrlFlags | ZX Spectrum +2A / +3 secondary control flags. |
| Ula128MemFlags | ZX Spectrum 128K / +2 memory control flags and +2A / +3 primary control flags. |
| UlaPlusRegFlags | ULAplus register port flags. |
| UlaPortFlags | ZX Spectrum's ULA port flags. |
Enums
| ReadEarMode | This enum determines the EAR input (bit 6) read from the 0xFE port when there is no EAR input feed. |
| Ula3Paging |
Traits
| ControlUnit | This trait provides the interface for running the emulation and accessing instances of peripheral devices. |
| EarIn | A trait for feeding the EAR line input. |
| FrameState | The trait for reading and modifying the state of frame and cycle counters. |
| HostConfig | A helper trait for accessing parameters of well-known host configurations. |
| InnerAccess | A generic trait, useful for chipset implementations based on other underlying implementations. |
| MemoryAccess | A trait for directly accessing an emulated memory implementation and memory extensions. |
| MicOut | A trait for reading the MIC line output. |
Functions
| duration_from_frame_tc_cpu_hz | Returns a duration from the number of T-states in a single frame and a CPU clock rate. |
| nanos_from_frame_tc_cpu_hz | Returns the number of nanoseconds from the number of T-states in a single frame and a CPU clock rate. |