[−][src]Struct spectrusty_core::chip::ScldCtrlFlags
Timex TC2048/TC2068/TS2068 screen and memory control flags.
Implementations
impl ScldCtrlFlags[src]
pub const SCREEN_MODE_MASK: ScldCtrlFlags[src]
pub const SCREEN_SOURCE_MASK: ScldCtrlFlags[src]
pub const SCREEN_SECONDARY: ScldCtrlFlags[src]
pub const SCREEN_HI_ATTRS: ScldCtrlFlags[src]
pub const SCREEN_HI_RES: ScldCtrlFlags[src]
pub const HIRES_COLOR_MASK: ScldCtrlFlags[src]
pub const INTR_DISABLED: ScldCtrlFlags[src]
pub const MAP_EX_ROM: ScldCtrlFlags[src]
pub const fn empty() -> ScldCtrlFlags[src]
Returns an empty set of flags
pub const fn all() -> ScldCtrlFlags[src]
Returns the set containing all flags.
pub const fn bits(&self) -> u8[src]
Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u8) -> Option<ScldCtrlFlags>[src]
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub const fn from_bits_truncate(bits: u8) -> ScldCtrlFlags[src]
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
pub const unsafe fn from_bits_unchecked(bits: u8) -> ScldCtrlFlags[src]
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
pub const fn is_empty(&self) -> bool[src]
Returns true if no flags are currently stored.
pub const fn is_all(&self) -> bool[src]
Returns true if all flags are currently set.
pub const fn intersects(&self, other: ScldCtrlFlags) -> bool[src]
Returns true if there are flags common to both self and other.
pub const fn contains(&self, other: ScldCtrlFlags) -> bool[src]
Returns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: ScldCtrlFlags)[src]
Inserts the specified flags in-place.
pub fn remove(&mut self, other: ScldCtrlFlags)[src]
Removes the specified flags in-place.
pub fn toggle(&mut self, other: ScldCtrlFlags)[src]
Toggles the specified flags in-place.
pub fn set(&mut self, other: ScldCtrlFlags, value: bool)[src]
Inserts or removes the specified flags depending on the passed value.
impl ScldCtrlFlags[src]
pub fn into_plus_mode(self) -> UlaPlusRegFlags[src]
Returns scren mode with hi-res colors from flags as ULAplus register flags in mode group.
pub fn hires_color_index(self) -> u8[src]
Returns a color index from high resolution color mask: [0, 7].
pub fn is_map_ex_rom(self) -> bool[src]
Returns true if a map ex rom bit is 1. Otherwise returns false.
pub fn is_intr_disabled(self) -> bool[src]
Returns true if a interrupt disabled bit is 1. Otherwise returns false.
pub fn is_screen_hi_res(self) -> bool[src]
Returns true if a screen high resolution bit is 1. Otherwise returns false.
pub fn is_screen_hi_attrs(self) -> bool[src]
Returns true if a screen high color bit is 1. Otherwise returns false.
pub fn is_screen_secondary(self) -> bool[src]
Returns true if a screen secondary bit is 1. Otherwise returns false.