[−][src]Trait spectrusty_core::chip::HostConfig
A helper trait for accessing parameters of well-known host configurations.
Associated Constants
pub const CPU_HZ: u32[src]
The number of CPU cycles (T-states) per second.
pub const FRAME_TSTATES: FTs[src]
The number of CPU cycles (T-states) in a single execution frame.
Provided methods
pub fn effective_cpu_rate(multiplier: f64) -> f64[src]
Returns the CPU rate (T-states / second) after multiplying it by the multiplier.
pub fn effective_frame_duration_nanos(multiplier: f64) -> u32[src]
Returns the duration of a single execution frame in nanoseconds after multiplying
the CPU rate by the multiplier.
pub fn effective_frame_duration(multiplier: f64) -> Duration[src]
Returns the duration of a single execution frame after multiplying the CPU rate by
the multiplier.
pub fn frame_duration_nanos() -> u32[src]
Returns the duration of a single execution frame in nanoseconds.
pub fn frame_duration() -> Duration[src]
Returns the duration of a single execution frame.