[−][src]Module spectrusty_core::clock
T-state timestamp types and counters.
Structs
| FTsData1 | A timestamp with packed N-bits of data. |
| FTsData2 | A timestamp with packed N-bits of data. |
| FTsData3 | A timestamp with packed N-bits of data. |
| VFrameTs | A VideoTs timestamp wrapper with a constraint to the |
| VFrameTsCounter | A generic |
| VideoTs | A timestamp type that consists of two video counters: vertical and horizontal. |
| VideoTsData1 | A timestamp with packed N-bits of data. |
| VideoTsData2 | A timestamp with packed N-bits of data. |
| VideoTsData3 | A timestamp with packed N-bits of data. |
| VideoTsData6 | A timestamp with packed N-bits of data. |
Constants
| HALT_VC_THRESHOLD | If a vertical counter of VideoTs exceeds this value, it signals the control unit to emulate hanging CPU indefinitely. |
Traits
| MemoryContention | A trait used by VFrameTsCounter for checking if an |
| TimestampOps | A trait providing calculation methods for timestamps. |
Type Definitions
| FTs | A linear T-state timestamp type. |
| Ts | A type used for a horizontal T-state timestamp or a video scanline index for VideoTs. |